% This file is part of the OPTPDE problem collection
%                 http://www.optpde.net
% It is provided as is, without any warranty, under the 
%
% Creative Commons Attribution-NonCommercial ShareAlike 4.0 International
%
%         http://creativecommons.org/licenses/by-nc-sa/4.0/
%
% Please give proper credits when using this file by referencing the 
% collection. For this purpose detailed bibliography data is 
% available at the collections website 
%                  
%                 http://www.optpde.net
%
% This file contains data for the benchmark problem 
%                      ccquas1
% from  2022-04-01 


% setup the problem
problem = setup_problem;

% generate a grid on the time-space domain
[x1,x2] = meshgrid(linspace(0,pi,41),linspace(0,pi,41));

% plot the leading coefficient for y = 1
figure(1); clf; hold on
val = a(problem,x1,x2,ones(size(x1)));
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('leading coefficient a for y = 1');
view(3);

% plot the potential term for y = 1
figure(2); clf; hold on
val = f(problem,x1,x2,ones(size(x1)));
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('potential term f for y = 1');
view(3);

% plot the domain right hand side function
figure(3); clf; hold on
val = g1(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('domain right hand side g_1');
view(3);

% plot the boundary right hand side function
figure(4); clf; hold on
val = g2(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('boundary right hand side g_2');
view(3);

% plot the auxiliary term e
figure(5); clf; hold on
val = e(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('auxiliary term e');
view(3);

% plot the coefficient in the objective eta
figure(6); clf; hold on
val = eta(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('coefficient in the objective \eta');
view(3);

% plot the desired state 
figure(7); clf; hold on
val = yOmega(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('desired state y_\Omega');
view(3);

% plot the optimal state 
figure(8); clf; hold on
val = supplementary_y(problem,x1,x2);
surf(x1,x2,val);
xlabel('x_1');
ylabel('x_2');
title('optimal state y');
view(3);

% plot the optimal control
figure(9); clf; hold on
b1 = linspace(0,pi,41); b2 = zeros(size(b1));
val = supplementary_u(problem,b1,b2);
plot3(b1,b2,val);
b1 = linspace(0,pi,41); b2 = pi*ones(size(b1));
val = supplementary_u(problem,b1,b2);
plot3(b1,b2,val);
b2 = linspace(0,pi,41); b1 = zeros(size(b1));
val = supplementary_u(problem,b1,b2);
plot3(b1,b2,val);
b2 = linspace(0,pi,41); b1 = pi*ones(size(b1));
val = supplementary_u(problem,b1,b2);
plot3(b1,b2,val);
xlabel('x_1');
ylabel('x_2');
title('optimal control u');
view(3);

